require "fi/path"
require "fileutils"

module Fi
  class Dir
    def self.current
      ::Dir.pwd
    end

    @previous_dir = current
    @history = [current]

    def self.change(dir=home)
      @history << current
      ::Dir.chdir dir
    end

    def self.back
      change(@history.pop || current)
    end

    def self.list(path=current)
      directories = list! path
      directories.reject { |d| d =~ /^\./ }
    end

    def self.list!(path=current)
      ::Dir.entries Path.expand(path)
    end

    def self.exist?(dirname)
      ::Dir.exist? dirname
    end

    def self.delete(dir)
      FileUtils.rm_r dir
    end

    def self.delete!(dir)
      FileUtils.rm_rf dir
    end

    def self.rename(dirname, name)
      FileUtils.mv dirname, name
    end

    def self.home(user=nil)
      return ::Dir.home user if user
      ::Dir.home
    end

    def initialize(*dirs)
      dirs.each do |dir|
        ::FileUtils.mkdir_p dir
      end
    end
  end
end
